@@ -6,9 +6,11 @@ import torch
 
 import nncore
 from nncore.nn import build_model
+from nncore.optim import build_optimizer
+from nncore.utils import CfgNode
 from .buffer import Buffer
 from .builder import build_dataloader, build_hook
-from .comm import gather, is_distributed, is_main_process, synchronize
+from .comm import gather, is_distributed, is_main_process, sync
 from .hooks import Hook
 from .utils import get_checkpoint, load_checkpoint
 
@@ -181,7 +183,7 @@ class Engine(object):
         log_file = nncore.join(self.work_dir, time_str + '.log')
         self.logger = nncore.get_logger(logger, log_file=log_file)
 
-        self.buffer = Buffer(max_size=buffer_size, logger=logger)
+        self.buffer = Buffer(max_size=buffer_size, logger=self.logger)
         self.reset_states()
 
     @property
@@ -288,57 +290,33 @@ class Engine(object):
             hook = hook.name
         self.hooks.pop(hook)
 
-    def build_optimizer(self, optimizer):
-        """
-        Build an optimizer for the engine.
-
-        Args:
-            optimizer (:obj:`optim.Optimizer` | dict): The optimizer or an
-                optimizer config used for constructing the optimizer.
-        """
-        if isinstance(optimizer, torch.optim.Optimizer):
-            self.optimizer = optimizer
-        elif isinstance(optimizer, dict):
-            self.optimizer = nncore.build_object(
-                optimizer, torch.optim, params=self.model.parameters())
-        else:
-            raise TypeError(
-                "optimizer should be an optim.Optimizer object or a dict, but "
-                "got: '{}'".format(optimizer))
-
-    def load_checkpoint(self, checkpoint, strict=False):
+    def load_checkpoint(self, checkpoint, **kwargs):
         """
         Load checkpoint from a file or an URL.
 
         Args:
             checkpoint (dict | str): A dict, a filename, an URL or a
                 ``torchvision://<model_name>`` str indicating the checkpoint.
-            strict (bool, optional): Whether to allow different params for the
-                model and checkpoint. If ``True``, raise an error when the
-                params do not match exactly. Default: ``False``.
         """
         load_checkpoint(
             self.model,
             checkpoint,
             map_location=next(self.model.parameters()).device,
-            strict=strict,
-            logger=self.logger)
+            logger=self.logger,
+            **kwargs)
 
         if isinstance(checkpoint, str):
             self.logger.info('Loaded checkpoint from {}'.format(checkpoint))
         else:
             self.logger.info('Loaded checkpoint')
 
-    def resume(self, checkpoint, strict=False):
+    def resume(self, checkpoint, **kwargs):
         """
         Resume from a checkpoint file.
 
         Args:
             checkpoint (dict | str): A dict, a filename or an URL indicatin
                 the checkpoint.
-            strict (bool, optional): Whether to allow different params for the
-                model and checkpoint. If ``True``, raise an error when the
-                params do not match exactly. Default: ``False``.
         """
         if isinstance(checkpoint, str):
             checkpoint = get_checkpoint(
@@ -347,11 +325,12 @@ class Engine(object):
         if self.stages != checkpoint['meta']['stages']:
             self.logger.warn(
                 'Stages in the engine and checkpoint are mismatch:'
-                '\n\nCurrent stages: {}\n\nCheckpoint stages: {}'.format(
-                    self.stages, checkpoint['meta']['stages']))
+                '\n\nCurrent stages: {}\n\nCheckpoint stages: {}'.format([
+                    c.to_dict() if isinstance(c, CfgNode) else c
+                    for c in self.stages
+                ], checkpoint['meta']['stages']))
 
-        load_checkpoint(
-            self.model, checkpoint, strict=strict, logger=self.logger)
+        load_checkpoint(self.model, checkpoint, logger=self.logger, **kwargs)
 
         self._epoch = checkpoint['meta']['epoch']
         self._iter = self._start_iter = checkpoint['meta']['iter']
@@ -364,7 +343,8 @@ class Engine(object):
         self._stage = count
 
         if 'optimizer' in checkpoint:
-            self.build_optimizer(self.cur_stage['optimizer'])
+            self.optimizer = build_optimizer(
+                self.cur_stage['optimizer'], params=self.model.parameters())
             self.optimizer.load_state_dict(checkpoint['optimizer'])
         else:
             raise KeyError('optimizer not found in the checkpoint')
@@ -479,7 +459,8 @@ class Engine(object):
             self._stage + 1, self.cur_stage['epochs'], optim))
 
         if self.epoch_in_stage == 0:
-            self.build_optimizer(self.cur_stage['optimizer'])
+            self.optimizer = build_optimizer(
+                self.cur_stage['optimizer'], params=self.model.parameters())
 
         self._call_hook('before_stage')
 
@@ -505,12 +486,20 @@ class Engine(object):
 
         if is_main_process():
             blob = nncore.concat(blob)
+
+            cfg = self.cur_stage.get('validation')
+            if cfg is not None:
+                cfg.pop('interval', None)
+                cfg.pop('offset', None)
+            else:
+                cfg = dict()
+
             output = self.data_loader.dataset.evaluate(
-                blob, logger=self.logger)
+                blob, logger=self.logger, **cfg)
         else:
             output = dict()
 
-        synchronize()
+        sync()
         return output
 
     def launch(self, eval=False, **kwargs):
