@@ -1,7 +1,6 @@
 # Copyright (c) Ye Liu. All rights reserved.
 
 from .base import Hook
-from .builder import HOOKS, build_hook
 from .checkpoint import CheckpointHook
 from .closure import ClosureHook
 from .eval import EvalHook
@@ -15,8 +14,8 @@ from .sampler_seed import SamplerSeedHook
 from .timer import TimerHook
 
 __all__ = [
-    'Hook', 'HOOKS', 'build_hook', 'CheckpointHook', 'ClosureHook', 'EvalHook',
-    'CommandLineWriter', 'EventWriterHook', 'JSONWriter', 'TensorboardWriter',
-    'LrUpdaterHook', 'EmptyCacheHook', 'OptimizerHook', 'PreciseBNHook',
-    'SamplerSeedHook', 'TimerHook'
+    'Hook', 'CheckpointHook', 'ClosureHook', 'EvalHook', 'CommandLineWriter',
+    'EventWriterHook', 'JSONWriter', 'TensorboardWriter', 'LrUpdaterHook',
+    'EmptyCacheHook', 'OptimizerHook', 'PreciseBNHook', 'SamplerSeedHook',
+    'TimerHook'
 ]
