@@ -2,11 +2,13 @@
 
 from .colorspace import (bgr2gray, bgr2hls, bgr2hsv, bgr2rgb, gray2bgr,
                          gray2rgb, hls2bgr, hsv2bgr, rgb2bgr, rgb2gray)
+from .geometric import imrescale, imresize, imresize_like, rescale_size
 from .io import imread, imwrite
 from .normalize import imdenormalize, imnormalize
 
 __all__ = [
     'bgr2gray', 'bgr2hls', 'bgr2hsv', 'bgr2rgb', 'gray2bgr', 'gray2rgb',
-    'hls2bgr', 'hsv2bgr', 'rgb2bgr', 'rgb2gray', 'imread', 'imwrite',
-    'imdenormalize', 'imnormalize'
+    'hls2bgr', 'hsv2bgr', 'rgb2bgr', 'rgb2gray', 'imrescale', 'imresize',
+    'imresize_like', 'rescale_size', 'imread', 'imwrite', 'imdenormalize',
+    'imnormalize'
 ]
