@@ -3,8 +3,11 @@
 from .bbox import (bbox_area, bbox_intersection, bbox_iof, bbox_iou,
                    remove_small_bboxes)
 from .data import cosine_similarity
+from .temporal import (temporal_area, temporal_intersection, temporal_iof,
+                       temporal_iou)
 
 __all__ = [
     'bbox_area', 'bbox_intersection', 'bbox_iof', 'bbox_iou',
-    'remove_small_bboxes', 'cosine_similarity'
+    'remove_small_bboxes', 'cosine_similarity', 'temporal_area',
+    'temporal_intersection', 'temporal_iof', 'temporal_iou'
 ]
